@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '1.16'; 
+$VERSION = '1.1601'; 
 $VERSION = eval $VERSION;
 
 use Config;
@@ -140,12 +140,9 @@ HERE
     $tee_input .= " $redirect" if defined $redirect;
     {
       # ensure autoflush
-      require Devel::Autoflush;
-      my $inc_path = $INC{'Devel/Autoflush.pm'};
-      $inc_path =~ s{/Devel/Autoflush.pm$}{};
       local $ENV{PERL5OPT} = $ENV{PERL5OPT} || q{};
       $ENV{PERL5OPT} .= q{ } if length $ENV{PERL5OPT};
-      $ENV{PERL5OPT} .= "-I$inc_path -MDevel::Autoflush";
+      $ENV{PERL5OPT} .= "-MDevel::Autoflush";
       tee($tee_input, { stderr => 1 }, $temp_out);
     }
 
@@ -1143,11 +1140,16 @@ sub _temp_filename {
 sub _timeout_wrapper {
     my ($cmd, $timeout) = @_;
     
-    eval "use Proc::Killfam ()";
+    # Check Proc::ProcessTable also in case an unauthorized Proc::Killfam is
+    # present, as from Tk-ExecuteCommand
+    {
+      local $SIG{__WARN__} = sub {};  # protect against v-string warning
+      eval "require Proc::ProcessTable; require Proc::Killfam";
+    }
     if ($@) {
         $CPAN::Frontend->mywarn( << 'HERE' );
-CPAN::Reporter: you need Proc::Killfam for inactivity_timeout support.
-Continuing without timeout...
+CPAN::Reporter: you need Proc::ProcessTable and Proc::Killfam for 
+inactivity_timeout support.  Continuing without timeout...
 HERE
         return;
     }
